==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/events/HotRodAuthEventEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.events;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodAuthEventEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity, org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.events.Event.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.events.Event.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity, org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity.HotRodAuthEventEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-21.1.2-sources.jar: org/keycloak/models/map/storage/hotRod/events/HotRodAuthEventEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.events;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodAuthEventEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity, org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.events.Event.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.events.Event.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity, org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAuthEventEntity.HotRodAuthEventEntitySchema.INSTANCE;
    }
}
